@@ -3,11 +3,13 @@ import sys
 import datetime
 import requests
 import subprocess as s
+import time
+from rich.progress import Progress
 
 def logo():
   logo = '''
 █▀▀ █ ▀█▀ █▀▄ █░█ █▀▄▀█ █▀█  version
-█▄█ █ ░█░ █▄▀ █▄█ █░▀░█ █▀▀  1.0.1  
+█▄█ █ ░█░ █▄▀ █▄█ █░▀░█ █▀▀  1.0.2  
   '''
   return logo
   
@@ -54,8 +56,13 @@ def clone(dir, url):
 
 def dump(dir, rl):
   mkdir(dir)
+  with Progress() as progress:
+    dump_progress_bar = progress.add_task("[red]\[gitdump] (status)> ", total=len(rl))
     
-  for i in range(len(rl)):
-    url = rl[i]['html_url']
-    print(f'[gitdump] (dumping)> {url}')
-    clone(dir, url)
\ No newline at end of file
+    for i in range(len(rl)):
+      progress.update(dump_progress_bar, advance=1)
+      url = rl[i]['html_url']
+      print(f'[gitdump] (dumping)> {url}')
+      clone(dir, url)
+        
+              
